@@ -4,7 +4,7 @@ from __future__ import annotations
 
 from datetime import date, time
 from enum import Enum
-from typing import Optional
+from typing import Optional, List
 
 from pydantic import BaseModel, Field
 
@@ -112,7 +112,7 @@ class Subject(BaseModel):
     home_cage_enrichment: Optional[HomeCageEnrichment] = Field(
         None, title="Home cage enrichment"
     )
-    wellness_report: Optional[WellnessReport] = Field(
+    wellness_reports: Optional[List[WellnessReport]] = Field(
         None, title="Wellness Report"
     )
     notes: Optional[str] = Field(None, title="Notes")
